@@ -301,6 +301,13 @@ public class ServerDescriptorImplTest {
       return db.buildDescriptor();
     }
 
+    private String routerFamilyCertLines = "family-cert\n"
+        + "-----BEGIN FAMILY CERT-----\n"
+        + "o4j+kH8UQfjBwepUnr99v0ebN8RpzHJ/lqYsTojXHy9kMr1RNI9IDeSzA7PSqT"
+        + "uV\n4PL8QsGtlfwthtIoZpB2srZeyN/mcpA9fa1JXUrt/UN9K/+32Cyaad7h0n"
+        + "HE6Xfb\njqpXDpnBpvk4zjmzjjKYnIsUWTnADmu0fo3xTRqXi7g=\n"
+        + "-----END FAMILY CERT-----";
+
     private String routerSignatureLines = "router-signature\n"
         + "-----BEGIN SIGNATURE-----\n"
         + "o4j+kH8UQfjBwepUnr99v0ebN8RpzHJ/lqYsTojXHy9kMr1RNI9IDeSzA7PSqT"
@@ -315,6 +322,13 @@ public class ServerDescriptorImplTest {
       return db.buildDescriptor();
     }
 
+    private static ServerDescriptor createWithFamilyCertLines(
+        String line) throws DescriptorParseException {
+      DescriptorBuilder db = new DescriptorBuilder();
+      db.routerFamilyCertLines = line;
+      return db.buildDescriptor();
+    }
+
     private String unrecognizedLine = null;
 
     private static ServerDescriptor createWithUnrecognizedLine(String line)
@@ -462,6 +476,9 @@ public class ServerDescriptorImplTest {
           if (this.routerSignatureLines != null) {
             baos.write(this.routerSignatureLines.getBytes());
           }
+          if (this.routerFamilyCertLines != null) {
+            baos.write(this.routerFamilyCertLines.getBytes());
+          }
           return baos.toByteArray();
         } catch (IOException e) {
           return null;
@@ -473,6 +490,9 @@ public class ServerDescriptorImplTest {
       if (this.routerSignatureLines != null) {
         sb.append(this.routerSignatureLines).append("\n");
       }
+      if (this.routerFamilyCertLines != null) {
+        sb.append(this.routerFamilyCertLines).append("\n");
+      }
       return sb.toString().getBytes();
     }
 
@@ -1786,6 +1806,15 @@ public class ServerDescriptorImplTest {
     assertEquals(unrecognizedLines, descriptor.getUnrecognizedLines());
   }
 
+  private static final String FAMILY_CERT_LINES =
+      "family-cert\n"
+      + "-----BEGIN FAMILY CERT-----\n"
+      + "AQQABiX1AVGv5BuzJroQXbOh6vv1nbwc5rh2S13PyRFuLhTiifK4AQAgBACBCMwr"
+      + "\n4qgIlFDIzoC9ieJOtSkwrK+yXJPKlP8ojvgkx8cGKvhokOwA1eYDombzfwHcJ1"
+      + "EV\nbhEn/6g8i7wzO3LoqefIUrSAeEExOAOmm5mNmUIzL8EtnT6JHCr/sqUTUgA="
+      + "\n"
+      + "-----END FAMILY CERT-----";
+
   private static final String IDENTITY_ED25519_LINES =
       "identity-ed25519\n"
       + "-----BEGIN ED25519 CERT-----\n"
@@ -1818,6 +1847,16 @@ public class ServerDescriptorImplTest {
         descriptor.getRouterSignatureEd25519());
   }
 
+  @Test
+  public void testFamilyCert() throws DescriptorParseException {
+    ServerDescriptor descriptor =
+        DescriptorBuilder.createWithFamilyCertLines(
+            this.FAMILY_CERT_LINES);
+    assertEquals(this.FAMILY_CERT_LINES.substring(
+            this.FAMILY_CERT_LINES.indexOf("\n") + 1),
+        descriptor.getFamilyCert());
+  }
+
   @Test
   public void testEd25519IdentityMasterKeyMismatch()
       throws DescriptorParseException {
