@@ -1,4 +1,4 @@
-/* Copyright 2011--2020 The Tor Project
+/* Copyright 2011--2024 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.descriptor.impl;
@@ -718,7 +718,11 @@ public class RelayNetworkStatusVoteImplTest {
         nse.getVersion());
     assertTrue(nse.getMicrodescriptorDigestsSha256Base64().contains(
         "9ciEx9t0McXk9A06I7qwN7pxuNOdpCP64RV/6cx2Zkc"));
-    assertEquals("8,9,10,11", nse.getSupportedConsensusMethods());
+    assertEquals("[8,9,10,11]",
+        nse.getSupportedConsensusMethods().toString());
+    assertEquals(
+        "{9ciEx9t0McXk9A06I7qwN7pxuNOdpCP64RV/6cx2Zkc=[8, 9, 10, 11]}",
+        nse.getHashToConsensusMethods().toString());
     assertEquals(3, vote.getDirKeyCertificateVersion());
     assertEquals("80550987E1D626E3EBA5E5E75A458DE0626D088C",
         vote.getIdentity());
